@@ -67,7 +67,7 @@ static int my_##func(int c) \
    return(func(c)); \
 }
 
-#define SUPPRESSED_ON_LINE(c)  (LineSuppressions & (1LL<<c))
+#define SUPPRESSED_ON_LINE(c)  (LineSuppressions & ((uint64_t)1<<c))
 
 #define INUSE(c) \
     ((LaTeXMsgs[(enum ErrNum) c].InUse == iuOK) && !SUPPRESSED_ON_LINE(c))
@@ -138,12 +138,12 @@ const char FileSuppDelim[] = "chktex-file ";
 /*
  * A bit field used to hold the suppressions for the current line.
  */
-static unsigned long long LineSuppressions;
+static uint64_t LineSuppressions;
 /*
  * A bit field used to hold the suppressions of numbered user warnings
  * for the current line.
  */
-static unsigned long long UserLineSuppressions;
+static uint64_t UserLineSuppressions;
 
 static unsigned long Line;
 
@@ -336,7 +336,7 @@ static char *PreProcess(void)
             if (!NoLineSupp)
             {
                 int error;
-                const int MaxSuppressionBits = sizeof(unsigned long long)*8-1;
+                const int MaxSuppressionBits = 63;
 
                 /* Convert to lowercase to compare with LineSuppDelim */
                 EscapePtr = ++TmpPtr; /* move past NUL terminator */
@@ -357,13 +357,13 @@ static char *PreProcess(void)
                     }
                     if (error > 0)
                     {
-                        FileSuppressions |= (1LL << error);
-                        LineSuppressions |= (1LL << error);
+                        FileSuppressions |= ((uint64_t)1 << error);
+                        LineSuppressions |= ((uint64_t)1 << error);
                     }
                     else
                     {
-                        UserFileSuppressions |= (1LL << (-error));
-                        UserLineSuppressions |= (1LL << (-error));
+                        UserFileSuppressions |= ((uint64_t)1 << (-error));
+                        UserLineSuppressions |= ((uint64_t)1 << (-error));
                     }
                 }
                 TmpPtr = EscapePtr;
@@ -380,11 +380,11 @@ static char *PreProcess(void)
 
                     if (error > 0)
                     {
-                        LineSuppressions |= (1LL << error);
+                        LineSuppressions |= ((uint64_t)1 << error);
                     }
                     else
                     {
-                        UserLineSuppressions |= (1LL << (-error));
+                        UserLineSuppressions |= ((uint64_t)1 << (-error));
                     }
                 }
             }
@@ -874,11 +874,11 @@ static void CheckRest(void)
             while (offset < len)
             {
                 /* Check if this warning should be suppressed. */
-                if (UserLineSuppressions != 0LL && NamedWarning)
+                if (UserLineSuppressions && NamedWarning)
                 {
                     /* The warning can be named with positive or negative numbers. */
                     int UserWarningNumber = abs(atoi(ErrMessage));
-                    if (UserLineSuppressions & (1LL << UserWarningNumber))
+                    if (UserLineSuppressions & ((uint64_t)1 << UserWarningNumber))
                     {
                         break;
                     }
@@ -918,7 +918,8 @@ static void CheckRest(void)
                         /* Default -- show the match */
                         PSERR2(offset + MATCH.rm_so, MATCH.rm_eo - MATCH.rm_so,
                                emUserWarnRegex,
-                               MATCH.rm_eo - MATCH.rm_so,
+                               /* The format specifier expects an int */
+                               (int)(MATCH.rm_eo - MATCH.rm_so),
                                TmpBuffer + offset + MATCH.rm_so);
                     }
                     offset += MATCH.rm_eo;
@@ -1019,11 +1020,11 @@ static void CheckDash(void)
  *
  */
 
-static void HandleBracket(int Char)
+static void HandleBracket(char Char)
 {
     unsigned long BrOffset;     /* Offset into BrOrder array */
     struct ErrInfo *ei;
-    int TmpC, Match;
+    char TmpC, Match;
     char ABuf[2], BBuf[2];
     char *TmpPtr;
 
@@ -1135,7 +1136,7 @@ int CheckSilentRegex(void)
 
 #if ! (HAVE_PCRE || HAVE_POSIX_ERE)
 
-    return HasWord(CmdBuffer, &Silent);
+    return HasWord(CmdBuffer, &Silent) != NULL;
 
 #else
 
@@ -1227,7 +1228,7 @@ int FindErr(const char *_RealBuf, const unsigned long _Line)
     char *TmpPtr;               /* Temporary pointer */
     char *ErrPtr;               /* Ptr to where an error started */
 
-    int TmpC,                   /* Just a temp var used throughout the proc. */
+    char TmpC,                  /* Just a temp var used throughout the proc. */
       MatchC, Char;             /* Char. currently processed */
     unsigned long CmdLen;       /* Length of misc. things */
     int MixingQuotes;
@@ -1370,12 +1371,15 @@ int FindErr(const char *_RealBuf, const unsigned long _Line)
                 break;
 
             case '.':
-                if ((Char == *BufPtr) && (Char == BufPtr[1]))
+                /* .. or ... should be ellipses */
+                if ((Char == *BufPtr) && (Char != PrePtr[0]))
                 {
                     const char *cTmpPtr;
-                    dotlev = CheckDots(&PrePtr[1], &BufPtr[2]);
+                    const int NumDots = (Char == BufPtr[1]) ? 3 : 2;
+                    dotlev = CheckDots(&PrePtr[1],
+                                       &BufPtr[NumDots-1]);
                     cTmpPtr = Dot2Str(dotlev);
-                    HEREA(3, emEllipsis, cTmpPtr);
+                    HEREA(NumDots, emEllipsis, cTmpPtr);
                 }
 
                 /* Regexp: "([^A-Z@.])\.[.!?:]*\s+[a-z]" */
@@ -1445,10 +1449,10 @@ int FindErr(const char *_RealBuf, const unsigned long _Line)
                 MixingQuotes = FALSE;
 
                 if ((*TmpPtr == MatchC) || (*TmpPtr == '\"') ||
-                    (*TmpPtr == ''))
+                    (*TmpPtr == '\xB4')) /* xB4 = latin1 acute accent */
                     MixingQuotes = TRUE;
 
-                SKIP_AHEAD(TmpPtr, TmpC, strchr("`\'\"", TmpC));
+                SKIP_AHEAD(TmpPtr, TmpC, strchr("`\'\"\xB4", TmpC)); /* xB4 = latin1 acute accent */
 
                 if (MixingQuotes)
                     HERE(TmpPtr - BufPtr + 1, emQuoteMix);
@@ -1497,11 +1501,7 @@ int FindErr(const char *_RealBuf, const unsigned long _Line)
                 HERE(1, emUseQuoteLiga);
                 break;
 
-                /* One of these are unnecessary, but what the heck... */
-            case 180:          /* . NOTE: '\xb4' gets converted to - something */
-            case ~(0xff & (~180)):     /* This yields 0xff...fb4 in */
-                /* arbitrary precision. */
-
+            case '\264':             /*  (in Latin-1) */
                 HERE(1, emUseOtherQuote);
                 break;
 
@@ -1795,6 +1795,8 @@ PrintError(const char *File, const char *String,
                         fputs(Delimit, OutputFile);
                         break;
                     case 'c':
+                        /* TODO: need to add the offset of the column
+                         * here when long lines are broken. */
                         fprintf(OutputFile, "%ld", Position + 1);
                         break;
                     case 'd':
