@@ -31,12 +31,7 @@
 #include "Resource.h"
 #include "OpSys.h"
 
-#ifdef ASM_HASHWORD
-extern unsigned short HashWord(const char *a);
-typedef unsigned short HASH_TYPE;
-#else
 typedef unsigned long HASH_TYPE;
-#endif
 
 /***************************** SUPPORT FUNCTIONS ************************/
 
@@ -389,14 +384,12 @@ int strinfront(const char *Str, const char *Cmp)
 /*************************** HASH INDEX **************************/
 
 /*
- * Hashes a string. The string ought be rather short. We use an asm
- * version the Amiga; note that this returns an unsigned short instead.
+ * Hashes a string. The string ought be rather short.
  *
  * The algorithm was designed by Peter Weinberger. This version was
  * adapted from Dr Dobb's Journal April 1996 page 26.
  */
 
-#ifndef ASM_HASHWORD
 static unsigned long HashWord(const char *str)
 {
     register unsigned long h = 0, hbit, c;
@@ -411,7 +404,6 @@ static unsigned long HashWord(const char *str)
 
     return (h);
 }
-#endif
 
 /*
  * Inserts a string into a hash index. Note: You'll have to
@@ -711,6 +703,7 @@ int PushFile(const char *Name, FILE * fh, struct Stack *stack)
 
 char *FGetsStk(char *Dest, unsigned long len, struct Stack *stack)
 {
+    static short HasSeenLong = 0;
     struct FileNode *fn;
     char *Retval = NULL;
 
@@ -722,13 +715,19 @@ char *FGetsStk(char *Dest, unsigned long len, struct Stack *stack)
             if (Retval) {
                 if (Retval[strlen(Retval)-1] == '\n')
                     fn->Line++;
+                /* We only want the long lines warning once per file */
+                else if (!HasSeenLong)
+                {
+                    PrintPrgErr(pmLongLines, BUFSIZ);
+                    HasSeenLong = 1;
+                }
                 break;
             }
 
             fn = StkPop(stack);
             fclose(fn->fh);
             free(fn);
-
+            HasSeenLong = 0;
         }
         while (!Retval && (fn = StkTop(stack)));
     }
